"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var webview_utils_common_1 = require("./webview-utils-common");
var WebViewUtils = (function (_super) {
    __extends(WebViewUtils, _super);
    function WebViewUtils() {
        var _this = _super.call(this) || this;
        _this.headersAddedTo = new Set();
        _this.isFirstLoad = true;
        return global.__native(_this);
    }
    WebViewUtils.setUserAgent = function (wv, userAgent) {
        wv.android.getSettings().setUserAgentString(userAgent);
    };
    WebViewUtils.addHeaders = function (wv, headers) {
        WebViewUtils.wv = wv;
        WebViewUtils.headers = headers;
        setTimeout(function () {
            wv.android.setWebViewClient(WebViewUtils.initWithView(wv));
        });
    };
    WebViewUtils.initWithView = function (view) {
        var client = new WebViewUtils();
        client._view = view;
        client._origClient = view._webViewClient;
        return client;
    };
    WebViewUtils.prototype.shouldOverrideUrlLoading = function (view, urlOrWebResourceRequest) {
        var url = typeof urlOrWebResourceRequest === "string" ? urlOrWebResourceRequest : urlOrWebResourceRequest.getUrl().toString();
        view.loadUrl(url, this.getAdditionalHeadersForUrl(url));
        return true;
    };
    WebViewUtils.prototype.onPageStarted = function (view, url, favicon) {
        _super.prototype.onPageStarted.call(this, view, url, favicon);
        var headersAdded = this.headersAddedTo.has(url);
        if (this._view && url.indexOf("http") === 0 && !headersAdded) {
            this._view.android.loadUrl(url, this.getAdditionalHeadersForUrl(url));
        }
        if (headersAdded && WebViewUtils.wv) {
            webview_utils_common_1.onLoadStarted(WebViewUtils.wv, url, undefined);
        }
    };
    WebViewUtils.prototype.onPageFinished = function (view, url) {
        _super.prototype.onPageFinished.call(this, view, url);
        if (!this.isFirstLoad && WebViewUtils.wv) {
            webview_utils_common_1.onLoadFinished(WebViewUtils.wv, url, undefined);
            this.isFirstLoad = true;
        }
        else {
            this.isFirstLoad = false;
        }
    };
    WebViewUtils.prototype.onReceivedError = function () {
        var view = arguments[0];
        if (arguments.length === 4) {
            var errorCode = arguments[1];
            var description = arguments[2];
            var failingUrl = arguments[3];
            _super.prototype.onReceivedError.call(this, view, errorCode, description, failingUrl);
            if (WebViewUtils.wv) {
                webview_utils_common_1.onLoadFinished(WebViewUtils.wv, failingUrl, description + "(" + errorCode + ")");
            }
        }
        else {
            var request = arguments[1];
            var error = arguments[2];
            _super.prototype.onReceivedError.call(this, view, request, error);
            var headersAdded = error.getUrl && this.headersAddedTo.has(error.getUrl());
            if (headersAdded && WebViewUtils.wv) {
                webview_utils_common_1.onLoadFinished(WebViewUtils.wv, error.getUrl && error.getUrl(), error.getDescription() + "(" + error.getErrorCode() + ")");
            }
        }
    };
    WebViewUtils.prototype.getAdditionalHeadersForUrl = function (url) {
        var headers = new java.util.HashMap();
        if (!this.headersAddedTo.has(url)) {
            WebViewUtils.headers.forEach(function (val, key) {
                headers.put(key, val);
            });
            this.headersAddedTo.add(url);
        }
        return headers;
    };
    return WebViewUtils;
}(android.webkit.WebViewClient));
exports.WebViewUtils = WebViewUtils;
